@@ -3,7 +3,8 @@ setClass(
   Class='nplr', 
   representation(
     x='numeric', 
-    y='numeric', 
+    y='numeric',
+    w='numeric',
     useLog='logical',
     npars='numeric', 
     LPweight='numeric',
@@ -13,8 +14,10 @@ setClass(
     inflPoint='data.frame', 
     goodness='numeric', 
     stdErr='numeric',
+    nlmErr='vector',
     pars='data.frame',
-    AUC='data.frame'),
+    AUC='data.frame',
+    call='ANY'),
   
   prototype = prototype(
     useLog = TRUE,
@@ -25,9 +28,11 @@ setClass(
     yCurve = numeric(), 
     inflPoint = data.frame(), 
     goodness = 0, 
-    stdErr = 0, 
+    stdErr = 0,
+    nlmErr = 0,
     pars = data.frame(),
-    AUC = data.frame()
+    AUC = data.frame(),
+    call=NULL
     )
 )
 
@@ -38,12 +43,16 @@ setMethod(
   definition = function(object){
     cat("Instance of class nplr\n")
     cat("\n")
+    cat("Call:\n")
+    print(object@call)
+    cat("\n")
     cat(sprintf("%s-P logistic model\n", object@npars))
     cat("Bottom asymptote:", getPar(object)$params$bottom, "\n")
     cat("Top asymptote:", getPar(object)$params$top, "\n")
     cat("Inflexion point at (x, y):", as.numeric(getInflexion(object)), "\n")
     cat("Goodness of fit:", getGoodness(object), "\n")
     cat("Standard error:", getStdErr(object), "\n")
+    cat("nlm error(s):", object@nlmErr, "\n")
     cat("\n")
   }
 )
